@@ -3,20 +3,27 @@ module for running
 PySQL Python Wrapper CLI
 """
 
+import os
+import sys
+# create relative path for importing modules
+sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
+
 try:
     import stdiomask
     import time
+    import urllib.request
     import packages.auth as auth
     import packages.ddl_commands as ddl
     import packages.dml_commands as dml
     import data.info as info
     import data.export as export
     import data.imports as imports
+    import data.update as update
 
 except:
     raise Exception("Package Error: modules not setup")
 
-__version__ = "1.0.2"
+__version__ = "1.0.5"
 
 print(info.ascii_art)
 time.sleep(1)
@@ -67,6 +74,23 @@ while (True):
         elif user_input.lower() in ["-v", "version"]:
             print(__version__ + "\n")
 
+        elif user_input.lower() in ["-u", "update"]:
+            gh_version = urllib.request.urlopen("https://raw.githubusercontent.com/Devansh3712/PySQL/main/pysql/__version__.py")
+            gh_version = gh_version.read().decode("utf-8")
+
+            if gh_version > __version__:
+
+                result = update.update_pysql()
+
+                if result is True:
+                    print(f"[+] PySQL updated to v{gh_version} succesfully\n")
+
+                else:
+                    print(f"[-] Unable to update PySQL\n")
+
+            else:
+                print(f"[+] PySQL is up-to-date\n")
+
         elif user_input.lower() == "ddl":
             print(info.data_definition_language)
 
