@@ -4,11 +4,16 @@ PySQL Python Wrapper CLI
 [colored version]
 """
 
+import os
+import sys
+# create relative path for importing modules
+sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
+
 try:
     import stdiomask
     import time
     import platform
-    import sys
+    import urllib.request
     from colorama import init, Fore, Style
     import packages.auth as auth
     import packages.ddl_commands as ddl
@@ -20,7 +25,7 @@ try:
 except:
     raise Exception("Package Error: modules not setup")
 
-__version__ = "1.0.2"
+__version__ = "1.0.5"
 
 if platform.system() == "Windows":
     init(convert = True)
@@ -74,6 +79,23 @@ while (True):
         elif user_input.lower() in ["-v", "version"]:
             print(__version__ + "\n")
 
+        elif user_input.lower() in ["-u", "update"]:
+            gh_version = urllib.request.urlopen("https://raw.githubusercontent.com/Devansh3712/PySQL/main/pysql/__version__.py")
+            gh_version = gh_version.read().decode("utf-8")
+
+            if gh_version > __version__:
+
+                result = update.update_pysql()
+
+                if result is True:
+                    print(f"[{Fore.GREEN}+{Style.RESET_ALL}]{Fore.GREEN} PySQL updated to v{gh_version} succesfully{Style.RESET_ALL}\n")
+
+                else:
+                    print(f"[{Fore.RED}-{Style.RESET_ALL}]{Fore.RED} Unable to update PySQL{Style.RESET_ALL}\n")
+
+            else:
+                print(f"[{Fore.GREEN}+{Style.RESET_ALL}]{Fore.GREEN} PySQL is up-to-date{Style.RESET_ALL}\n")
+
         elif user_input.lower() == "ddl":
             print(info.data_definition_language)
 
